@@ -14,6 +14,7 @@
  * limitations under the License.
  */
 
+#define CFP_LUCY
 #define C_LUCY_DOCREADER
 #define C_LUCY_DEFAULTDOCREADER
 #include "XSBind.h"
@@ -43,7 +44,7 @@ LUCY_DefDocReader_Fetch_Doc_IMP(lucy_DefaultDocReader *self, int32_t doc_id) {
     LUCY_InStream_Seek(ix_in, (int64_t)doc_id * 8);
     start = LUCY_InStream_Read_U64(ix_in);
     LUCY_InStream_Seek(dat_in, start);
-    num_fields = LUCY_InStream_Read_C32(dat_in);
+    num_fields = LUCY_InStream_Read_CU32(dat_in);
 
     // Decode stored data and build up the doc field by field.
     while (num_fields--) {
@@ -53,7 +54,7 @@ LUCY_DefDocReader_Fetch_Doc_IMP(lucy_DefaultDocReader *self, int32_t doc_id) {
         lucy_FieldType *type;
 
         // Read field name.
-        field_name_len = LUCY_InStream_Read_C32(dat_in);
+        field_name_len = LUCY_InStream_Read_CU32(dat_in);
         field_name_ptr = SvGROW(field_name_sv, field_name_len + 1);
         LUCY_InStream_Read_Bytes(dat_in, field_name_ptr, field_name_len);
         SvPOK_on(field_name_sv);
@@ -69,7 +70,7 @@ LUCY_DefDocReader_Fetch_Doc_IMP(lucy_DefaultDocReader *self, int32_t doc_id) {
         // Read the field value.
         switch (LUCY_FType_Primitive_ID(type) & lucy_FType_PRIMITIVE_ID_MASK) {
             case lucy_FType_TEXT: {
-                    STRLEN value_len = LUCY_InStream_Read_C32(dat_in);
+                    STRLEN value_len = LUCY_InStream_Read_CU32(dat_in);
                     value_sv = newSV((value_len ? value_len : 1));
                     LUCY_InStream_Read_Bytes(dat_in, SvPVX(value_sv), value_len);
                     SvCUR_set(value_sv, value_len);
@@ -79,7 +80,7 @@ LUCY_DefDocReader_Fetch_Doc_IMP(lucy_DefaultDocReader *self, int32_t doc_id) {
                     break;
                 }
             case lucy_FType_BLOB: {
-                    STRLEN value_len = LUCY_InStream_Read_C32(dat_in);
+                    STRLEN value_len = LUCY_InStream_Read_CU32(dat_in);
                     value_sv = newSV((value_len ? value_len : 1));
                     LUCY_InStream_Read_Bytes(dat_in, SvPVX(value_sv), value_len);
                     SvCUR_set(value_sv, value_len);
@@ -94,15 +95,15 @@ LUCY_DefDocReader_Fetch_Doc_IMP(lucy_DefaultDocReader *self, int32_t doc_id) {
                 value_sv = newSVnv(LUCY_InStream_Read_F64(dat_in));
                 break;
             case lucy_FType_INT32:
-                value_sv = newSViv((int32_t)LUCY_InStream_Read_C32(dat_in));
+                value_sv = newSViv(LUCY_InStream_Read_CI32(dat_in));
                 break;
             case lucy_FType_INT64:
                 if (sizeof(IV) == 8) {
-                    int64_t val = (int64_t)LUCY_InStream_Read_C64(dat_in);
+                    int64_t val = LUCY_InStream_Read_CI64(dat_in);
                     value_sv = newSViv((IV)val);
                 }
                 else { // (lossy)
-                    int64_t val = (int64_t)LUCY_InStream_Read_C64(dat_in);
+                    int64_t val = LUCY_InStream_Read_CI64(dat_in);
                     value_sv = newSVnv((double)val);
                 }
                 break;
